@@ -66,7 +66,6 @@ public class MC3000GathererThread extends Thread {
 	boolean							isPortOpenedByLiveGatherer	= false;
 	boolean							isGatheredRecordSetVisible	= true;
 	boolean							isCollectDataStopped				= false;
-	UsbInterface				usbInterface								= null;
 	boolean							isProgrammExecuting1				= false;
 	boolean							isProgrammExecuting2				= false;
 	boolean							isProgrammExecuting3				= false;
@@ -104,7 +103,7 @@ public class MC3000GathererThread extends Thread {
 		this.channel = this.channels.get(this.channelNumber);
 
 		if (!this.usbPort.isConnected()) {
-			this.usbInterface = this.usbPort.openUsbPort(this.device);
+			this.usbPort.openUsbPort();
 			this.isPortOpenedByLiveGatherer = true;
 		}
 		this.setPriority(Thread.MAX_PRIORITY);
@@ -165,22 +164,22 @@ public class MC3000GathererThread extends Thread {
 							this.application.setSerialRxOn();
 						}
 						//get data from device for all4 slots
-						if (this.usbPort.isConnected()) dataBuffer1 = this.usbPort.getData(this.usbInterface, MC3000UsbPort.TakeMtuData.SLOT_0.value());
+						if (this.usbPort.isConnected()) dataBuffer1 = this.usbPort.getData(MC3000UsbPort.TakeMtuData.SLOT_0.value());
 						WaitTimer.delay(USB_QUERY_DELAY);
-						if (this.usbPort.isConnected()) dataBuffer2 = this.usbPort.getData(this.usbInterface, MC3000UsbPort.TakeMtuData.SLOT_1.value());
+						if (this.usbPort.isConnected()) dataBuffer2 = this.usbPort.getData(MC3000UsbPort.TakeMtuData.SLOT_1.value());
 						if (this.application != null) this.application.setSerialTxOff();
 						WaitTimer.delay(USB_QUERY_DELAY);
-						if (this.usbPort.isConnected()) dataBuffer3 = this.usbPort.getData(this.usbInterface, MC3000UsbPort.TakeMtuData.SLOT_2.value());
+						if (this.usbPort.isConnected()) dataBuffer3 = this.usbPort.getData(MC3000UsbPort.TakeMtuData.SLOT_2.value());
 						WaitTimer.delay(USB_QUERY_DELAY);
-						if (this.usbPort.isConnected()) dataBuffer4 = this.usbPort.getData(this.usbInterface, MC3000UsbPort.TakeMtuData.SLOT_3.value());
+						if (this.usbPort.isConnected()) dataBuffer4 = this.usbPort.getData(MC3000UsbPort.TakeMtuData.SLOT_3.value());
 						if (this.application != null) this.application.setSerialRxOff();
 
 						if (dataBuffer1 != null && dataBuffer1.length >= 6 && dataBuffer1[5] == 4) --retryCounterEnd_1_sec;
 						this.isProgrammExecuting1 = this.device.isProcessing(1, dataBuffer1) && retryCounterEnd_1_sec >= 0;
 						if (this.isProgrammExecuting1 && !this.wasProgrammExecuting1) {
 							this.wasProgrammExecuting1 = this.isProgrammExecuting1;
-							this.retryCounterEnd_1_sec = this.device.new SlotSettings(this.usbPort.getSlotData(this.usbInterface,
-									QuerySlotData.SLOT_0.value()), this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
+							this.retryCounterEnd_1_sec = this.device.new SlotSettings(this.usbPort.getSlotData(QuerySlotData.SLOT_0.value()), 
+									this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
 							log.log(Level.OFF, "Resting time slot 1 [min] " + retryCounterEnd_1_sec/60);
 						} else if (!this.isProgrammExecuting1) {
 							this.wasProgrammExecuting1 = this.isProgrammExecuting1;
@@ -189,8 +188,8 @@ public class MC3000GathererThread extends Thread {
 						this.isProgrammExecuting2 = this.device.isProcessing(2, dataBuffer2) && retryCounterEnd_2_sec >= 0;
 						if (this.isProgrammExecuting2 && !this.wasProgrammExecuting2) {
 							this.wasProgrammExecuting2 = this.isProgrammExecuting2;
-							this.retryCounterEnd_2_sec = this.device.new SlotSettings(this.usbPort.getSlotData(this.usbInterface,
-									QuerySlotData.SLOT_1.value()), this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
+							this.retryCounterEnd_2_sec = this.device.new SlotSettings(this.usbPort.getSlotData(QuerySlotData.SLOT_1.value()), 
+									this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
 							log.log(Level.OFF, "Resting time slot 2 [min] " + retryCounterEnd_2_sec/60);
 						} else if (!this.isProgrammExecuting2) {
 							this.wasProgrammExecuting2 = this.isProgrammExecuting2;
@@ -199,8 +198,8 @@ public class MC3000GathererThread extends Thread {
 						this.isProgrammExecuting3 = this.device.isProcessing(3, dataBuffer3) && retryCounterEnd_3_sec >= 0;
 						if (this.isProgrammExecuting3 && !this.wasProgrammExecuting3) {
 							this.wasProgrammExecuting3 = this.isProgrammExecuting3;
-							this.retryCounterEnd_3_sec = this.device.new SlotSettings(this.usbPort.getSlotData(this.usbInterface,
-									QuerySlotData.SLOT_2.value()), this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
+							this.retryCounterEnd_3_sec = this.device.new SlotSettings(this.usbPort.getSlotData(QuerySlotData.SLOT_2.value()), 
+									this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
 							log.log(Level.OFF, "Resting time slot 3 [min] " + retryCounterEnd_3_sec/60);
 						} else if (!this.isProgrammExecuting3) {
 							this.wasProgrammExecuting3 = this.isProgrammExecuting3;
@@ -209,8 +208,8 @@ public class MC3000GathererThread extends Thread {
 						this.isProgrammExecuting4 = this.device.isProcessing(4, dataBuffer4) && retryCounterEnd_4_sec >= 0;
 						if (this.isProgrammExecuting4 && !this.wasProgrammExecuting4) {
 							this.wasProgrammExecuting4 = this.isProgrammExecuting4;
-							this.retryCounterEnd_4_sec = this.device.new SlotSettings(this.usbPort.getSlotData(this.usbInterface,
-									QuerySlotData.SLOT_3.value()), this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
+							this.retryCounterEnd_4_sec = this.device.new SlotSettings(this.usbPort.getSlotData(QuerySlotData.SLOT_3.value()), 
+									this.device.getFirmwareVersionAsInt()).getChargeRestingTime()*60; 
 							log.log(Level.OFF, "Resting time slot 4 [min] " + retryCounterEnd_4_sec/60);
 						} else if (!this.isProgrammExecuting4) {
 							this.wasProgrammExecuting4 = this.isProgrammExecuting4;
@@ -404,8 +403,8 @@ public class MC3000GathererThread extends Thread {
 		}
 		finally {
 			try {
-				if (this.usbInterface != null) {
-					this.device.usbPort.closeUsbPort(this.usbInterface);
+				if (this.device.usbPort.libUsbHandle != null) {
+					this.device.usbPort.closeUsbPort(false);
 					MC3000GathererThread.log.log(Level.FINE, "USB interface closed");
 				}
 			}
@@ -491,7 +490,7 @@ public class MC3000GathererThread extends Thread {
 					this.channels.switchChannel(slotChannel.getNumber(), processRecordSetKey);
 				slotChannel.switchRecordSet(processRecordSetKey);
 				String description = String.format("%s%s%s %s; Memory # %02d", 
-						recordSet.getRecordSetDescription(), GDE.LINE_SEPARATOR, this.device.getHardwareString(), this.device.getFirmwareString(), this.device.getBatteryMemoryNumber(number, this.usbInterface)); //$NON-NLS-1$
+						recordSet.getRecordSetDescription(), GDE.LINE_SEPARATOR, this.device.getHardwareString(), this.device.getFirmwareString(), this.device.getBatteryMemoryNumber(number)); //$NON-NLS-1$
 				recordSet.setRecordSetDescription(description);
 			}
 
@@ -628,8 +627,4 @@ public class MC3000GathererThread extends Thread {
 	boolean isCollectDataStopped() {
 		return this.isCollectDataStopped;
 	}
-	
-	public UsbInterface getUsbInterface() {
-		return this.usbInterface;
-	}
 }
